;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "docker" "20251028.1026"
  "Interface to Docker."
  '((aio       "1.0")
    (dash      "2.19.1")
    (emacs     "28.1")
    (s         "1.13.0")
    (tablist   "1.1")
    (transient "0.4.3"))
  :url "https://github.com/Silex/docker.el"
  :commit "375e0ed45bb1edc655d9ae2943a09864bec1fcba"
  :revdesc "375e0ed45bb1"
  :keywords '("filename" "convenience")
  :authors '(("Philippe Vaucher" . "philippe.vaucher@gmail.com"))
  :maintainers '(("Philippe Vaucher" . "philippe.vaucher@gmail.com")))
